# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20035ResponsePolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'default': 'str',
        'policy_index': 'int',
        'num_regions': 'int',
        'replication_mode': 'str',
        'policy_type': 'int',
        'system': 'str',
        'number_of_mirrors': 'int',
        'data_fragments': 'int',
        'parity_fragments': 'int',
        'ring_version': 'int',
        'type': 'str',
        'state': 'str',
        'health_status': 'str',
        'health_percentage': 'str',
        'rebalance_status': 'str',
        'rebalance_percentage': 'str',
        'total_drives': 'int',
        'capacity': 'int',
        'gb_per_month_cost': 'float',
        'capacity_mode': 'str',
        'capacity_history_min': 'int',
        'alert_mode_min': 'int',
        'emergency_mode_percentage': 'int',
        'can_reconfig': 'int',
        'partition_percent_normal': 'float',
        'partition_percent_degraded': 'float',
        'partition_percent_critical': 'float',
        'partition_count_normal': 'int',
        'partition_count_degraded': 'int',
        'partition_count_critical': 'int',
        'partition_count_total': 'int',
        'short_description': 'str',
        'full_description': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'reported_at': 'str',
        'rebalanced_at': 'str',
        'disks_count': 'int',
        'disks': 'list[InlineResponse20015ResponseDisks]'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'default': 'default',
        'policy_index': 'policy_index',
        'num_regions': 'num_regions',
        'replication_mode': 'replication_mode',
        'policy_type': 'policy_type',
        'system': 'system',
        'number_of_mirrors': 'number_of_mirrors',
        'data_fragments': 'data_fragments',
        'parity_fragments': 'parity_fragments',
        'ring_version': 'ring_version',
        'type': 'type',
        'state': 'state',
        'health_status': 'health_status',
        'health_percentage': 'health_percentage',
        'rebalance_status': 'rebalance_status',
        'rebalance_percentage': 'rebalance_percentage',
        'total_drives': 'total_drives',
        'capacity': 'capacity',
        'gb_per_month_cost': 'gb_per_month_cost',
        'capacity_mode': 'capacity_mode',
        'capacity_history_min': 'capacity_history_min',
        'alert_mode_min': 'alert_mode_min',
        'emergency_mode_percentage': 'emergency_mode_percentage',
        'can_reconfig': 'can_reconfig',
        'partition_percent_normal': 'partition_percent_normal',
        'partition_percent_degraded': 'partition_percent_degraded',
        'partition_percent_critical': 'partition_percent_critical',
        'partition_count_normal': 'partition_count_normal',
        'partition_count_degraded': 'partition_count_degraded',
        'partition_count_critical': 'partition_count_critical',
        'partition_count_total': 'partition_count_total',
        'short_description': 'short_description',
        'full_description': 'full_description',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'reported_at': 'reported_at',
        'rebalanced_at': 'rebalanced_at',
        'disks_count': 'disks_count',
        'disks': 'disks'
    }

    def __init__(self, name=None, display_name=None, default=None, policy_index=None, num_regions=None, replication_mode=None, policy_type=None, system=None, number_of_mirrors=None, data_fragments=None, parity_fragments=None, ring_version=None, type=None, state=None, health_status=None, health_percentage=None, rebalance_status=None, rebalance_percentage=None, total_drives=None, capacity=None, gb_per_month_cost=None, capacity_mode=None, capacity_history_min=None, alert_mode_min=None, emergency_mode_percentage=None, can_reconfig=None, partition_percent_normal=None, partition_percent_degraded=None, partition_percent_critical=None, partition_count_normal=None, partition_count_degraded=None, partition_count_critical=None, partition_count_total=None, short_description=None, full_description=None, created_at=None, modified_at=None, reported_at=None, rebalanced_at=None, disks_count=None, disks=None, _configuration=None):  # noqa: E501
        """InlineResponse20035ResponsePolicy - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._default = None
        self._policy_index = None
        self._num_regions = None
        self._replication_mode = None
        self._policy_type = None
        self._system = None
        self._number_of_mirrors = None
        self._data_fragments = None
        self._parity_fragments = None
        self._ring_version = None
        self._type = None
        self._state = None
        self._health_status = None
        self._health_percentage = None
        self._rebalance_status = None
        self._rebalance_percentage = None
        self._total_drives = None
        self._capacity = None
        self._gb_per_month_cost = None
        self._capacity_mode = None
        self._capacity_history_min = None
        self._alert_mode_min = None
        self._emergency_mode_percentage = None
        self._can_reconfig = None
        self._partition_percent_normal = None
        self._partition_percent_degraded = None
        self._partition_percent_critical = None
        self._partition_count_normal = None
        self._partition_count_degraded = None
        self._partition_count_critical = None
        self._partition_count_total = None
        self._short_description = None
        self._full_description = None
        self._created_at = None
        self._modified_at = None
        self._reported_at = None
        self._rebalanced_at = None
        self._disks_count = None
        self._disks = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if default is not None:
            self.default = default
        if policy_index is not None:
            self.policy_index = policy_index
        if num_regions is not None:
            self.num_regions = num_regions
        if replication_mode is not None:
            self.replication_mode = replication_mode
        if policy_type is not None:
            self.policy_type = policy_type
        if system is not None:
            self.system = system
        if number_of_mirrors is not None:
            self.number_of_mirrors = number_of_mirrors
        if data_fragments is not None:
            self.data_fragments = data_fragments
        if parity_fragments is not None:
            self.parity_fragments = parity_fragments
        if ring_version is not None:
            self.ring_version = ring_version
        if type is not None:
            self.type = type
        if state is not None:
            self.state = state
        if health_status is not None:
            self.health_status = health_status
        if health_percentage is not None:
            self.health_percentage = health_percentage
        if rebalance_status is not None:
            self.rebalance_status = rebalance_status
        if rebalance_percentage is not None:
            self.rebalance_percentage = rebalance_percentage
        if total_drives is not None:
            self.total_drives = total_drives
        if capacity is not None:
            self.capacity = capacity
        if gb_per_month_cost is not None:
            self.gb_per_month_cost = gb_per_month_cost
        if capacity_mode is not None:
            self.capacity_mode = capacity_mode
        if capacity_history_min is not None:
            self.capacity_history_min = capacity_history_min
        if alert_mode_min is not None:
            self.alert_mode_min = alert_mode_min
        if emergency_mode_percentage is not None:
            self.emergency_mode_percentage = emergency_mode_percentage
        if can_reconfig is not None:
            self.can_reconfig = can_reconfig
        if partition_percent_normal is not None:
            self.partition_percent_normal = partition_percent_normal
        if partition_percent_degraded is not None:
            self.partition_percent_degraded = partition_percent_degraded
        if partition_percent_critical is not None:
            self.partition_percent_critical = partition_percent_critical
        if partition_count_normal is not None:
            self.partition_count_normal = partition_count_normal
        if partition_count_degraded is not None:
            self.partition_count_degraded = partition_count_degraded
        if partition_count_critical is not None:
            self.partition_count_critical = partition_count_critical
        if partition_count_total is not None:
            self.partition_count_total = partition_count_total
        if short_description is not None:
            self.short_description = short_description
        if full_description is not None:
            self.full_description = full_description
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if reported_at is not None:
            self.reported_at = reported_at
        if rebalanced_at is not None:
            self.rebalanced_at = rebalanced_at
        if disks_count is not None:
            self.disks_count = disks_count
        if disks is not None:
            self.disks = disks

    @property
    def name(self):
        """Gets the name of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The name of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20035ResponsePolicy.


        :param name: The name of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The display_name of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20035ResponsePolicy.


        :param display_name: The display_name of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def default(self):
        """Gets the default of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The default of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this InlineResponse20035ResponsePolicy.


        :param default: The default of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._default = default

    @property
    def policy_index(self):
        """Gets the policy_index of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The policy_index of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._policy_index

    @policy_index.setter
    def policy_index(self, policy_index):
        """Sets the policy_index of this InlineResponse20035ResponsePolicy.


        :param policy_index: The policy_index of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._policy_index = policy_index

    @property
    def num_regions(self):
        """Gets the num_regions of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The num_regions of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._num_regions

    @num_regions.setter
    def num_regions(self, num_regions):
        """Sets the num_regions of this InlineResponse20035ResponsePolicy.


        :param num_regions: The num_regions of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._num_regions = num_regions

    @property
    def replication_mode(self):
        """Gets the replication_mode of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The replication_mode of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._replication_mode

    @replication_mode.setter
    def replication_mode(self, replication_mode):
        """Sets the replication_mode of this InlineResponse20035ResponsePolicy.


        :param replication_mode: The replication_mode of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._replication_mode = replication_mode

    @property
    def policy_type(self):
        """Gets the policy_type of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The policy_type of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._policy_type

    @policy_type.setter
    def policy_type(self, policy_type):
        """Sets the policy_type of this InlineResponse20035ResponsePolicy.


        :param policy_type: The policy_type of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._policy_type = policy_type

    @property
    def system(self):
        """Gets the system of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The system of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this InlineResponse20035ResponsePolicy.


        :param system: The system of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._system = system

    @property
    def number_of_mirrors(self):
        """Gets the number_of_mirrors of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The number_of_mirrors of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._number_of_mirrors

    @number_of_mirrors.setter
    def number_of_mirrors(self, number_of_mirrors):
        """Sets the number_of_mirrors of this InlineResponse20035ResponsePolicy.


        :param number_of_mirrors: The number_of_mirrors of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._number_of_mirrors = number_of_mirrors

    @property
    def data_fragments(self):
        """Gets the data_fragments of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The data_fragments of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._data_fragments

    @data_fragments.setter
    def data_fragments(self, data_fragments):
        """Sets the data_fragments of this InlineResponse20035ResponsePolicy.


        :param data_fragments: The data_fragments of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._data_fragments = data_fragments

    @property
    def parity_fragments(self):
        """Gets the parity_fragments of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The parity_fragments of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._parity_fragments

    @parity_fragments.setter
    def parity_fragments(self, parity_fragments):
        """Sets the parity_fragments of this InlineResponse20035ResponsePolicy.


        :param parity_fragments: The parity_fragments of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._parity_fragments = parity_fragments

    @property
    def ring_version(self):
        """Gets the ring_version of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The ring_version of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._ring_version

    @ring_version.setter
    def ring_version(self, ring_version):
        """Sets the ring_version of this InlineResponse20035ResponsePolicy.


        :param ring_version: The ring_version of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._ring_version = ring_version

    @property
    def type(self):
        """Gets the type of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The type of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InlineResponse20035ResponsePolicy.


        :param type: The type of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def state(self):
        """Gets the state of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The state of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InlineResponse20035ResponsePolicy.


        :param state: The state of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def health_status(self):
        """Gets the health_status of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The health_status of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._health_status

    @health_status.setter
    def health_status(self, health_status):
        """Sets the health_status of this InlineResponse20035ResponsePolicy.


        :param health_status: The health_status of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._health_status = health_status

    @property
    def health_percentage(self):
        """Gets the health_percentage of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The health_percentage of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._health_percentage

    @health_percentage.setter
    def health_percentage(self, health_percentage):
        """Sets the health_percentage of this InlineResponse20035ResponsePolicy.


        :param health_percentage: The health_percentage of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._health_percentage = health_percentage

    @property
    def rebalance_status(self):
        """Gets the rebalance_status of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The rebalance_status of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._rebalance_status

    @rebalance_status.setter
    def rebalance_status(self, rebalance_status):
        """Sets the rebalance_status of this InlineResponse20035ResponsePolicy.


        :param rebalance_status: The rebalance_status of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._rebalance_status = rebalance_status

    @property
    def rebalance_percentage(self):
        """Gets the rebalance_percentage of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The rebalance_percentage of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._rebalance_percentage

    @rebalance_percentage.setter
    def rebalance_percentage(self, rebalance_percentage):
        """Sets the rebalance_percentage of this InlineResponse20035ResponsePolicy.


        :param rebalance_percentage: The rebalance_percentage of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._rebalance_percentage = rebalance_percentage

    @property
    def total_drives(self):
        """Gets the total_drives of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The total_drives of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._total_drives

    @total_drives.setter
    def total_drives(self, total_drives):
        """Sets the total_drives of this InlineResponse20035ResponsePolicy.


        :param total_drives: The total_drives of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._total_drives = total_drives

    @property
    def capacity(self):
        """Gets the capacity of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The capacity of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this InlineResponse20035ResponsePolicy.


        :param capacity: The capacity of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def gb_per_month_cost(self):
        """Gets the gb_per_month_cost of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The gb_per_month_cost of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: float
        """
        return self._gb_per_month_cost

    @gb_per_month_cost.setter
    def gb_per_month_cost(self, gb_per_month_cost):
        """Sets the gb_per_month_cost of this InlineResponse20035ResponsePolicy.


        :param gb_per_month_cost: The gb_per_month_cost of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: float
        """

        self._gb_per_month_cost = gb_per_month_cost

    @property
    def capacity_mode(self):
        """Gets the capacity_mode of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The capacity_mode of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._capacity_mode

    @capacity_mode.setter
    def capacity_mode(self, capacity_mode):
        """Sets the capacity_mode of this InlineResponse20035ResponsePolicy.


        :param capacity_mode: The capacity_mode of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._capacity_mode = capacity_mode

    @property
    def capacity_history_min(self):
        """Gets the capacity_history_min of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The capacity_history_min of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._capacity_history_min

    @capacity_history_min.setter
    def capacity_history_min(self, capacity_history_min):
        """Sets the capacity_history_min of this InlineResponse20035ResponsePolicy.


        :param capacity_history_min: The capacity_history_min of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._capacity_history_min = capacity_history_min

    @property
    def alert_mode_min(self):
        """Gets the alert_mode_min of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The alert_mode_min of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._alert_mode_min

    @alert_mode_min.setter
    def alert_mode_min(self, alert_mode_min):
        """Sets the alert_mode_min of this InlineResponse20035ResponsePolicy.


        :param alert_mode_min: The alert_mode_min of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._alert_mode_min = alert_mode_min

    @property
    def emergency_mode_percentage(self):
        """Gets the emergency_mode_percentage of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The emergency_mode_percentage of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._emergency_mode_percentage

    @emergency_mode_percentage.setter
    def emergency_mode_percentage(self, emergency_mode_percentage):
        """Sets the emergency_mode_percentage of this InlineResponse20035ResponsePolicy.


        :param emergency_mode_percentage: The emergency_mode_percentage of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._emergency_mode_percentage = emergency_mode_percentage

    @property
    def can_reconfig(self):
        """Gets the can_reconfig of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The can_reconfig of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._can_reconfig

    @can_reconfig.setter
    def can_reconfig(self, can_reconfig):
        """Sets the can_reconfig of this InlineResponse20035ResponsePolicy.


        :param can_reconfig: The can_reconfig of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._can_reconfig = can_reconfig

    @property
    def partition_percent_normal(self):
        """Gets the partition_percent_normal of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The partition_percent_normal of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: float
        """
        return self._partition_percent_normal

    @partition_percent_normal.setter
    def partition_percent_normal(self, partition_percent_normal):
        """Sets the partition_percent_normal of this InlineResponse20035ResponsePolicy.


        :param partition_percent_normal: The partition_percent_normal of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: float
        """

        self._partition_percent_normal = partition_percent_normal

    @property
    def partition_percent_degraded(self):
        """Gets the partition_percent_degraded of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The partition_percent_degraded of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: float
        """
        return self._partition_percent_degraded

    @partition_percent_degraded.setter
    def partition_percent_degraded(self, partition_percent_degraded):
        """Sets the partition_percent_degraded of this InlineResponse20035ResponsePolicy.


        :param partition_percent_degraded: The partition_percent_degraded of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: float
        """

        self._partition_percent_degraded = partition_percent_degraded

    @property
    def partition_percent_critical(self):
        """Gets the partition_percent_critical of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The partition_percent_critical of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: float
        """
        return self._partition_percent_critical

    @partition_percent_critical.setter
    def partition_percent_critical(self, partition_percent_critical):
        """Sets the partition_percent_critical of this InlineResponse20035ResponsePolicy.


        :param partition_percent_critical: The partition_percent_critical of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: float
        """

        self._partition_percent_critical = partition_percent_critical

    @property
    def partition_count_normal(self):
        """Gets the partition_count_normal of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The partition_count_normal of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._partition_count_normal

    @partition_count_normal.setter
    def partition_count_normal(self, partition_count_normal):
        """Sets the partition_count_normal of this InlineResponse20035ResponsePolicy.


        :param partition_count_normal: The partition_count_normal of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._partition_count_normal = partition_count_normal

    @property
    def partition_count_degraded(self):
        """Gets the partition_count_degraded of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The partition_count_degraded of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._partition_count_degraded

    @partition_count_degraded.setter
    def partition_count_degraded(self, partition_count_degraded):
        """Sets the partition_count_degraded of this InlineResponse20035ResponsePolicy.


        :param partition_count_degraded: The partition_count_degraded of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._partition_count_degraded = partition_count_degraded

    @property
    def partition_count_critical(self):
        """Gets the partition_count_critical of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The partition_count_critical of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._partition_count_critical

    @partition_count_critical.setter
    def partition_count_critical(self, partition_count_critical):
        """Sets the partition_count_critical of this InlineResponse20035ResponsePolicy.


        :param partition_count_critical: The partition_count_critical of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._partition_count_critical = partition_count_critical

    @property
    def partition_count_total(self):
        """Gets the partition_count_total of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The partition_count_total of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._partition_count_total

    @partition_count_total.setter
    def partition_count_total(self, partition_count_total):
        """Sets the partition_count_total of this InlineResponse20035ResponsePolicy.


        :param partition_count_total: The partition_count_total of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._partition_count_total = partition_count_total

    @property
    def short_description(self):
        """Gets the short_description of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The short_description of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """Sets the short_description of this InlineResponse20035ResponsePolicy.


        :param short_description: The short_description of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._short_description = short_description

    @property
    def full_description(self):
        """Gets the full_description of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The full_description of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._full_description

    @full_description.setter
    def full_description(self, full_description):
        """Sets the full_description of this InlineResponse20035ResponsePolicy.


        :param full_description: The full_description of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._full_description = full_description

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The created_at of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20035ResponsePolicy.


        :param created_at: The created_at of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The modified_at of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20035ResponsePolicy.


        :param modified_at: The modified_at of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def reported_at(self):
        """Gets the reported_at of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The reported_at of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._reported_at

    @reported_at.setter
    def reported_at(self, reported_at):
        """Sets the reported_at of this InlineResponse20035ResponsePolicy.


        :param reported_at: The reported_at of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._reported_at = reported_at

    @property
    def rebalanced_at(self):
        """Gets the rebalanced_at of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The rebalanced_at of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: str
        """
        return self._rebalanced_at

    @rebalanced_at.setter
    def rebalanced_at(self, rebalanced_at):
        """Sets the rebalanced_at of this InlineResponse20035ResponsePolicy.


        :param rebalanced_at: The rebalanced_at of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: str
        """

        self._rebalanced_at = rebalanced_at

    @property
    def disks_count(self):
        """Gets the disks_count of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The disks_count of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: int
        """
        return self._disks_count

    @disks_count.setter
    def disks_count(self, disks_count):
        """Sets the disks_count of this InlineResponse20035ResponsePolicy.


        :param disks_count: The disks_count of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: int
        """

        self._disks_count = disks_count

    @property
    def disks(self):
        """Gets the disks of this InlineResponse20035ResponsePolicy.  # noqa: E501


        :return: The disks of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :rtype: list[InlineResponse20015ResponseDisks]
        """
        return self._disks

    @disks.setter
    def disks(self, disks):
        """Sets the disks of this InlineResponse20035ResponsePolicy.


        :param disks: The disks of this InlineResponse20035ResponsePolicy.  # noqa: E501
        :type: list[InlineResponse20015ResponseDisks]
        """

        self._disks = disks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20035ResponsePolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20035ResponsePolicy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20035ResponsePolicy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200133ResponseObsRestoreJobs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'mode': 'str',
        'obs_key': 'str',
        'status': 'str',
        'rpo': 'str',
        'avg_sync_rate_kb_sec': 'str',
        'cur_sync_rate_kb_sec': 'str',
        'shipping_position_mb': 'int',
        'total_capacity_mb': 'str',
        'already_restored_mb': 'int',
        'remaining_time_sec': 'int',
        'created_at': 'str',
        'modified_at': 'str',
        'src': 'InlineResponse200133ResponseSrc',
        'dst': 'InlineResponse200133ResponseDst'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'mode': 'mode',
        'obs_key': 'obs_key',
        'status': 'status',
        'rpo': 'rpo',
        'avg_sync_rate_kb_sec': 'avg_sync_rate_kb_sec',
        'cur_sync_rate_kb_sec': 'cur_sync_rate_kb_sec',
        'shipping_position_mb': 'shipping_position_mb',
        'total_capacity_mb': 'total_capacity_mb',
        'already_restored_mb': 'already_restored_mb',
        'remaining_time_sec': 'remaining_time_sec',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'src': 'src',
        'dst': 'dst'
    }

    def __init__(self, name=None, display_name=None, mode=None, obs_key=None, status=None, rpo=None, avg_sync_rate_kb_sec=None, cur_sync_rate_kb_sec=None, shipping_position_mb=None, total_capacity_mb=None, already_restored_mb=None, remaining_time_sec=None, created_at=None, modified_at=None, src=None, dst=None, _configuration=None):  # noqa: E501
        """InlineResponse200133ResponseObsRestoreJobs - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._mode = None
        self._obs_key = None
        self._status = None
        self._rpo = None
        self._avg_sync_rate_kb_sec = None
        self._cur_sync_rate_kb_sec = None
        self._shipping_position_mb = None
        self._total_capacity_mb = None
        self._already_restored_mb = None
        self._remaining_time_sec = None
        self._created_at = None
        self._modified_at = None
        self._src = None
        self._dst = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if mode is not None:
            self.mode = mode
        if obs_key is not None:
            self.obs_key = obs_key
        if status is not None:
            self.status = status
        if rpo is not None:
            self.rpo = rpo
        if avg_sync_rate_kb_sec is not None:
            self.avg_sync_rate_kb_sec = avg_sync_rate_kb_sec
        if cur_sync_rate_kb_sec is not None:
            self.cur_sync_rate_kb_sec = cur_sync_rate_kb_sec
        if shipping_position_mb is not None:
            self.shipping_position_mb = shipping_position_mb
        if total_capacity_mb is not None:
            self.total_capacity_mb = total_capacity_mb
        if already_restored_mb is not None:
            self.already_restored_mb = already_restored_mb
        if remaining_time_sec is not None:
            self.remaining_time_sec = remaining_time_sec
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if src is not None:
            self.src = src
        if dst is not None:
            self.dst = dst

    @property
    def name(self):
        """Gets the name of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The name of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200133ResponseObsRestoreJobs.


        :param name: The name of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The display_name of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse200133ResponseObsRestoreJobs.


        :param display_name: The display_name of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def mode(self):
        """Gets the mode of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The mode of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this InlineResponse200133ResponseObsRestoreJobs.


        :param mode: The mode of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: str
        """

        self._mode = mode

    @property
    def obs_key(self):
        """Gets the obs_key of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The obs_key of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: str
        """
        return self._obs_key

    @obs_key.setter
    def obs_key(self, obs_key):
        """Sets the obs_key of this InlineResponse200133ResponseObsRestoreJobs.


        :param obs_key: The obs_key of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: str
        """

        self._obs_key = obs_key

    @property
    def status(self):
        """Gets the status of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The status of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse200133ResponseObsRestoreJobs.


        :param status: The status of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def rpo(self):
        """Gets the rpo of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The rpo of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: str
        """
        return self._rpo

    @rpo.setter
    def rpo(self, rpo):
        """Sets the rpo of this InlineResponse200133ResponseObsRestoreJobs.


        :param rpo: The rpo of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: str
        """

        self._rpo = rpo

    @property
    def avg_sync_rate_kb_sec(self):
        """Gets the avg_sync_rate_kb_sec of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The avg_sync_rate_kb_sec of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: str
        """
        return self._avg_sync_rate_kb_sec

    @avg_sync_rate_kb_sec.setter
    def avg_sync_rate_kb_sec(self, avg_sync_rate_kb_sec):
        """Sets the avg_sync_rate_kb_sec of this InlineResponse200133ResponseObsRestoreJobs.


        :param avg_sync_rate_kb_sec: The avg_sync_rate_kb_sec of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: str
        """

        self._avg_sync_rate_kb_sec = avg_sync_rate_kb_sec

    @property
    def cur_sync_rate_kb_sec(self):
        """Gets the cur_sync_rate_kb_sec of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The cur_sync_rate_kb_sec of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: str
        """
        return self._cur_sync_rate_kb_sec

    @cur_sync_rate_kb_sec.setter
    def cur_sync_rate_kb_sec(self, cur_sync_rate_kb_sec):
        """Sets the cur_sync_rate_kb_sec of this InlineResponse200133ResponseObsRestoreJobs.


        :param cur_sync_rate_kb_sec: The cur_sync_rate_kb_sec of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: str
        """

        self._cur_sync_rate_kb_sec = cur_sync_rate_kb_sec

    @property
    def shipping_position_mb(self):
        """Gets the shipping_position_mb of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The shipping_position_mb of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: int
        """
        return self._shipping_position_mb

    @shipping_position_mb.setter
    def shipping_position_mb(self, shipping_position_mb):
        """Sets the shipping_position_mb of this InlineResponse200133ResponseObsRestoreJobs.


        :param shipping_position_mb: The shipping_position_mb of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: int
        """

        self._shipping_position_mb = shipping_position_mb

    @property
    def total_capacity_mb(self):
        """Gets the total_capacity_mb of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The total_capacity_mb of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: str
        """
        return self._total_capacity_mb

    @total_capacity_mb.setter
    def total_capacity_mb(self, total_capacity_mb):
        """Sets the total_capacity_mb of this InlineResponse200133ResponseObsRestoreJobs.


        :param total_capacity_mb: The total_capacity_mb of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: str
        """

        self._total_capacity_mb = total_capacity_mb

    @property
    def already_restored_mb(self):
        """Gets the already_restored_mb of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The already_restored_mb of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: int
        """
        return self._already_restored_mb

    @already_restored_mb.setter
    def already_restored_mb(self, already_restored_mb):
        """Sets the already_restored_mb of this InlineResponse200133ResponseObsRestoreJobs.


        :param already_restored_mb: The already_restored_mb of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: int
        """

        self._already_restored_mb = already_restored_mb

    @property
    def remaining_time_sec(self):
        """Gets the remaining_time_sec of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The remaining_time_sec of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: int
        """
        return self._remaining_time_sec

    @remaining_time_sec.setter
    def remaining_time_sec(self, remaining_time_sec):
        """Sets the remaining_time_sec of this InlineResponse200133ResponseObsRestoreJobs.


        :param remaining_time_sec: The remaining_time_sec of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: int
        """

        self._remaining_time_sec = remaining_time_sec

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The created_at of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse200133ResponseObsRestoreJobs.


        :param created_at: The created_at of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The modified_at of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse200133ResponseObsRestoreJobs.


        :param modified_at: The modified_at of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def src(self):
        """Gets the src of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The src of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: InlineResponse200133ResponseSrc
        """
        return self._src

    @src.setter
    def src(self, src):
        """Sets the src of this InlineResponse200133ResponseObsRestoreJobs.


        :param src: The src of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: InlineResponse200133ResponseSrc
        """

        self._src = src

    @property
    def dst(self):
        """Gets the dst of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501


        :return: The dst of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :rtype: InlineResponse200133ResponseDst
        """
        return self._dst

    @dst.setter
    def dst(self, dst):
        """Sets the dst of this InlineResponse200133ResponseObsRestoreJobs.


        :param dst: The dst of this InlineResponse200133ResponseObsRestoreJobs.  # noqa: E501
        :type: InlineResponse200133ResponseDst
        """

        self._dst = dst

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200133ResponseObsRestoreJobs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200133ResponseObsRestoreJobs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200133ResponseObsRestoreJobs):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Zios.api_client import ApiClient


class UsersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_new_user(self, add_new_user, **kwargs):  # noqa: E501
        """add_new_user  # noqa: E501

        Adds a new user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_new_user(add_new_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddNewUser add_new_user: (required)
        :return: InlineResponse20042
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_new_user_with_http_info(add_new_user, **kwargs)  # noqa: E501
        else:
            (data) = self.add_new_user_with_http_info(add_new_user, **kwargs)  # noqa: E501
            return data

    def add_new_user_with_http_info(self, add_new_user, **kwargs):  # noqa: E501
        """add_new_user  # noqa: E501

        Adds a new user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_new_user_with_http_info(add_new_user, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddNewUser add_new_user: (required)
        :return: InlineResponse20042
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['add_new_user']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_new_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'add_new_user' is set
        if self.api_client.client_side_validation and ('add_new_user' not in params or
                                                       params['add_new_user'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `add_new_user` when calling `add_new_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_new_user' in params:
            body_params = params['add_new_user']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/users.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20042',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_password(self, change_password, **kwargs):  # noqa: E501
        """change_password  # noqa: E501

        Change a user's password.  Permissions: account_admin, member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_password(change_password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ChangePassword change_password: (required)
        :return: InlineResponse20049
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_password_with_http_info(change_password, **kwargs)  # noqa: E501
        else:
            (data) = self.change_password_with_http_info(change_password, **kwargs)  # noqa: E501
            return data

    def change_password_with_http_info(self, change_password, **kwargs):  # noqa: E501
        """change_password  # noqa: E501

        Change a user's password.  Permissions: account_admin, member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_password_with_http_info(change_password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ChangePassword change_password: (required)
        :return: InlineResponse20049
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['change_password']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_password" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'change_password' is set
        if self.api_client.client_side_validation and ('change_password' not in params or
                                                       params['change_password'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `change_password` when calling `change_password`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_password' in params:
            body_params = params['change_password']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/password.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20049',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_user_pass_by_code(self, id, change_user_pass_by_code, **kwargs):  # noqa: E501
        """change_user_pass_by_code  # noqa: E501

        Change a user's password using a temporary password code.  Permissions: account_admin, member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_user_pass_by_code(id, change_user_pass_by_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param ChangeUserPassByCode change_user_pass_by_code: (required)
        :return: InlineResponse20050
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_user_pass_by_code_with_http_info(id, change_user_pass_by_code, **kwargs)  # noqa: E501
        else:
            (data) = self.change_user_pass_by_code_with_http_info(id, change_user_pass_by_code, **kwargs)  # noqa: E501
            return data

    def change_user_pass_by_code_with_http_info(self, id, change_user_pass_by_code, **kwargs):  # noqa: E501
        """change_user_pass_by_code  # noqa: E501

        Change a user's password using a temporary password code.  Permissions: account_admin, member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_user_pass_by_code_with_http_info(id, change_user_pass_by_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param ChangeUserPassByCode change_user_pass_by_code: (required)
        :return: InlineResponse20050
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'change_user_pass_by_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_user_pass_by_code" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `change_user_pass_by_code`")  # noqa: E501
        # verify the required parameter 'change_user_pass_by_code' is set
        if self.api_client.client_side_validation and ('change_user_pass_by_code' not in params or
                                                       params['change_user_pass_by_code'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `change_user_pass_by_code` when calling `change_user_pass_by_code`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_user_pass_by_code' in params:
            body_params = params['change_user_pass_by_code']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/{id}/password_code.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20050',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_user_role(self, user_id, change_user_role, **kwargs):  # noqa: E501
        """change_user_role  # noqa: E501

        Change a VPSA Object Storage user role.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_user_role(user_id, change_user_role, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: (required)
        :param ChangeUserRole change_user_role: (required)
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_user_role_with_http_info(user_id, change_user_role, **kwargs)  # noqa: E501
        else:
            (data) = self.change_user_role_with_http_info(user_id, change_user_role, **kwargs)  # noqa: E501
            return data

    def change_user_role_with_http_info(self, user_id, change_user_role, **kwargs):  # noqa: E501
        """change_user_role  # noqa: E501

        Change a VPSA Object Storage user role.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_user_role_with_http_info(user_id, change_user_role, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: (required)
        :param ChangeUserRole change_user_role: (required)
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'change_user_role']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_user_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in params or
                                                       params['user_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `change_user_role`")  # noqa: E501
        # verify the required parameter 'change_user_role' is set
        if self.api_client.client_side_validation and ('change_user_role' not in params or
                                                       params['change_user_role'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `change_user_role` when calling `change_user_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['user_id'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_user_role' in params:
            body_params = params['change_user_role']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/users/{user_id}/change_role.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20029',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_user(self, id, **kwargs):  # noqa: E501
        """delete_user  # noqa: E501

        Delete a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_user_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_user_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_user_with_http_info(self, id, **kwargs):  # noqa: E501
        """delete_user  # noqa: E501

        Delete a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/users/{id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20029',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def disable_admin_access(self, **kwargs):  # noqa: E501
        """disable_admin_access  # noqa: E501

        Disables cloud admin access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_admin_access(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20046
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.disable_admin_access_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.disable_admin_access_with_http_info(**kwargs)  # noqa: E501
            return data

    def disable_admin_access_with_http_info(self, **kwargs):  # noqa: E501
        """disable_admin_access  # noqa: E501

        Disables cloud admin access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_admin_access_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20046
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method disable_admin_access" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/admin_access/disable.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20046',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def disable_user(self, user_id, **kwargs):  # noqa: E501
        """disable_user  # noqa: E501

        Disable a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_user(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: (required)
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.disable_user_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.disable_user_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def disable_user_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """disable_user  # noqa: E501

        Disable a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_user_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: (required)
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method disable_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in params or
                                                       params['user_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `disable_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['user_id'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/users/{user_id}/disable.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20029',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def enable_cloud_admin_access(self, **kwargs):  # noqa: E501
        """enable_cloud_admin_access  # noqa: E501

        Enables cloud admin access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_cloud_admin_access(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20045
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.enable_cloud_admin_access_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.enable_cloud_admin_access_with_http_info(**kwargs)  # noqa: E501
            return data

    def enable_cloud_admin_access_with_http_info(self, **kwargs):  # noqa: E501
        """enable_cloud_admin_access  # noqa: E501

        Enables cloud admin access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_cloud_admin_access_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20045
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method enable_cloud_admin_access" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/admin_access/enable.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20045',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def enable_user(self, user_id, **kwargs):  # noqa: E501
        """enable_user  # noqa: E501

        Enable a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_user(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: (required)
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.enable_user_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.enable_user_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def enable_user_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """enable_user  # noqa: E501

        Enable a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_user_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: (required)
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method enable_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in params or
                                                       params['user_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `enable_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['user_id'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/users/{user_id}/enable.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20029',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_users(self, **kwargs):  # noqa: E501
        """get_all_users  # noqa: E501

        List all users.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20041
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_users_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_users  # noqa: E501

        List all users.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20041
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_users" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_all_users`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/users.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20041',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_auth_token(self, get_auth_token, **kwargs):  # noqa: E501
        """get_auth_token  # noqa: E501

        Returns a user's authentication token.  Permissions: account_admin, member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_auth_token(get_auth_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetAuthToken get_auth_token: (required)
        :return: InlineResponse20044
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_auth_token_with_http_info(get_auth_token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_auth_token_with_http_info(get_auth_token, **kwargs)  # noqa: E501
            return data

    def get_auth_token_with_http_info(self, get_auth_token, **kwargs):  # noqa: E501
        """get_auth_token  # noqa: E501

        Returns a user's authentication token.  Permissions: account_admin, member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_auth_token_with_http_info(get_auth_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetAuthToken get_auth_token: (required)
        :return: InlineResponse20044
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['get_auth_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_auth_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'get_auth_token' is set
        if self.api_client.client_side_validation and ('get_auth_token' not in params or
                                                       params['get_auth_token'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `get_auth_token` when calling `get_auth_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_auth_token' in params:
            body_params = params['get_auth_token']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/authenticate.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20044',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user(self, id, **kwargs):  # noqa: E501
        """get_user  # noqa: E501

        Show a single user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20043
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_user_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_user  # noqa: E501

        Show a single user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20043
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/users/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20043',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def issue_temp_code_to_mail(self, issue_temp_code_to_mail, **kwargs):  # noqa: E501
        """issue_temp_code_to_mail  # noqa: E501

        Issues a temporary password code to be sent by mail.  Permissions: account_admin, member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issue_temp_code_to_mail(issue_temp_code_to_mail, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IssueTempCodeToMail issue_temp_code_to_mail: (required)
        :return: InlineResponse20051
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.issue_temp_code_to_mail_with_http_info(issue_temp_code_to_mail, **kwargs)  # noqa: E501
        else:
            (data) = self.issue_temp_code_to_mail_with_http_info(issue_temp_code_to_mail, **kwargs)  # noqa: E501
            return data

    def issue_temp_code_to_mail_with_http_info(self, issue_temp_code_to_mail, **kwargs):  # noqa: E501
        """issue_temp_code_to_mail  # noqa: E501

        Issues a temporary password code to be sent by mail.  Permissions: account_admin, member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issue_temp_code_to_mail_with_http_info(issue_temp_code_to_mail, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IssueTempCodeToMail issue_temp_code_to_mail: (required)
        :return: InlineResponse20051
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['issue_temp_code_to_mail']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issue_temp_code_to_mail" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'issue_temp_code_to_mail' is set
        if self.api_client.client_side_validation and ('issue_temp_code_to_mail' not in params or
                                                       params['issue_temp_code_to_mail'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `issue_temp_code_to_mail` when calling `issue_temp_code_to_mail`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'issue_temp_code_to_mail' in params:
            body_params = params['issue_temp_code_to_mail']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/reset_password.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20051',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reset_token(self, reset_token, **kwargs):  # noqa: E501
        """reset_token  # noqa: E501

        Regenerate a user's authentication token.  Permissions: account_admin, member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reset_token(reset_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResetToken reset_token: (required)
        :return: InlineResponse20047
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.reset_token_with_http_info(reset_token, **kwargs)  # noqa: E501
        else:
            (data) = self.reset_token_with_http_info(reset_token, **kwargs)  # noqa: E501
            return data

    def reset_token_with_http_info(self, reset_token, **kwargs):  # noqa: E501
        """reset_token  # noqa: E501

        Regenerate a user's authentication token.  Permissions: account_admin, member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reset_token_with_http_info(reset_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResetToken reset_token: (required)
        :return: InlineResponse20047
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['reset_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reset_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'reset_token' is set
        if self.api_client.client_side_validation and ('reset_token' not in params or
                                                       params['reset_token'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `reset_token` when calling `reset_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'reset_token' in params:
            body_params = params['reset_token']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/users/reset_token.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20047',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reset_user_s3_keys(self, reset_user_s3_keys, **kwargs):  # noqa: E501
        """reset_user_s3_keys  # noqa: E501

        Reset a user's s3 access key and secret key.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reset_user_s3_keys(reset_user_s3_keys, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResetUserS3Keys reset_user_s3_keys: (required)
        :return: InlineResponse20048
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.reset_user_s3_keys_with_http_info(reset_user_s3_keys, **kwargs)  # noqa: E501
        else:
            (data) = self.reset_user_s3_keys_with_http_info(reset_user_s3_keys, **kwargs)  # noqa: E501
            return data

    def reset_user_s3_keys_with_http_info(self, reset_user_s3_keys, **kwargs):  # noqa: E501
        """reset_user_s3_keys  # noqa: E501

        Reset a user's s3 access key and secret key.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reset_user_s3_keys_with_http_info(reset_user_s3_keys, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResetUserS3Keys reset_user_s3_keys: (required)
        :return: InlineResponse20048
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['reset_user_s3_keys']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reset_user_s3_keys" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'reset_user_s3_keys' is set
        if self.api_client.client_side_validation and ('reset_user_s3_keys' not in params or
                                                       params['reset_user_s3_keys'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `reset_user_s3_keys` when calling `reset_user_s3_keys`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'reset_user_s3_keys' in params:
            body_params = params['reset_user_s3_keys']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/users/reset_s3_secret.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20048',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def show_bandwidth_throughput_metering_for_user(self, subserver, service, id, **kwargs):  # noqa: E501
        """show_bandwidth_throughput_metering_for_user  # noqa: E501

        Shows bandwidth throughput (B/s) metering for a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_bandwidth_throughput_metering_for_user(subserver, service, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subserver: e.g. object (required)
        :param str service: e.g. proxy (required)
        :param str id: (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :return: InlineResponse20014
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.show_bandwidth_throughput_metering_for_user_with_http_info(subserver, service, id, **kwargs)  # noqa: E501
        else:
            (data) = self.show_bandwidth_throughput_metering_for_user_with_http_info(subserver, service, id, **kwargs)  # noqa: E501
            return data

    def show_bandwidth_throughput_metering_for_user_with_http_info(self, subserver, service, id, **kwargs):  # noqa: E501
        """show_bandwidth_throughput_metering_for_user  # noqa: E501

        Shows bandwidth throughput (B/s) metering for a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_bandwidth_throughput_metering_for_user_with_http_info(subserver, service, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subserver: e.g. object (required)
        :param str service: e.g. proxy (required)
        :param str id: (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :return: InlineResponse20014
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['subserver', 'service', 'id', 'interval', 'count']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method show_bandwidth_throughput_metering_for_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'subserver' is set
        if self.api_client.client_side_validation and ('subserver' not in params or
                                                       params['subserver'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `subserver` when calling `show_bandwidth_throughput_metering_for_user`")  # noqa: E501
        # verify the required parameter 'service' is set
        if self.api_client.client_side_validation and ('service' not in params or
                                                       params['service'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `service` when calling `show_bandwidth_throughput_metering_for_user`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `show_bandwidth_throughput_metering_for_user`")  # noqa: E501

        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `show_bandwidth_throughput_metering_for_user`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('count' in params and params['count'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `count` when calling `show_bandwidth_throughput_metering_for_user`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'subserver' in params:
            query_params.append(('subserver', params['subserver']))  # noqa: E501
        if 'service' in params:
            query_params.append(('service', params['service']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/users/{id}/throughput.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20014',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def show_iops_metring_of_user(self, subserver, service, id, **kwargs):  # noqa: E501
        """show_iops_metring_of_user  # noqa: E501

        Shows IOPs metering for a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_iops_metring_of_user(subserver, service, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subserver: e.g. object (required)
        :param str service: e.g. proxy (required)
        :param str id: (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.show_iops_metring_of_user_with_http_info(subserver, service, id, **kwargs)  # noqa: E501
        else:
            (data) = self.show_iops_metring_of_user_with_http_info(subserver, service, id, **kwargs)  # noqa: E501
            return data

    def show_iops_metring_of_user_with_http_info(self, subserver, service, id, **kwargs):  # noqa: E501
        """show_iops_metring_of_user  # noqa: E501

        Shows IOPs metering for a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_iops_metring_of_user_with_http_info(subserver, service, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subserver: e.g. object (required)
        :param str service: e.g. proxy (required)
        :param str id: (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['subserver', 'service', 'id', 'interval', 'count']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method show_iops_metring_of_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'subserver' is set
        if self.api_client.client_side_validation and ('subserver' not in params or
                                                       params['subserver'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `subserver` when calling `show_iops_metring_of_user`")  # noqa: E501
        # verify the required parameter 'service' is set
        if self.api_client.client_side_validation and ('service' not in params or
                                                       params['service'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `service` when calling `show_iops_metring_of_user`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `show_iops_metring_of_user`")  # noqa: E501

        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `show_iops_metring_of_user`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('count' in params and params['count'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `count` when calling `show_iops_metring_of_user`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'subserver' in params:
            query_params.append(('subserver', params['subserver']))  # noqa: E501
        if 'service' in params:
            query_params.append(('service', params['service']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/users/{id}/iops.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20012',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def show_latency_metering_of_user(self, subserver, service, id, **kwargs):  # noqa: E501
        """show_latency_metering_of_user  # noqa: E501

        Shows latency (ms) metering for a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_latency_metering_of_user(subserver, service, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subserver: e.g. object (required)
        :param str service: e.g. proxy (required)
        :param str id: (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :return: InlineResponse20013
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.show_latency_metering_of_user_with_http_info(subserver, service, id, **kwargs)  # noqa: E501
        else:
            (data) = self.show_latency_metering_of_user_with_http_info(subserver, service, id, **kwargs)  # noqa: E501
            return data

    def show_latency_metering_of_user_with_http_info(self, subserver, service, id, **kwargs):  # noqa: E501
        """show_latency_metering_of_user  # noqa: E501

        Shows latency (ms) metering for a user.  Permissions: account_admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_latency_metering_of_user_with_http_info(subserver, service, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subserver: e.g. object (required)
        :param str service: e.g. proxy (required)
        :param str id: (required)
        :param int interval: The interval between data points, in seconds
        :param int count: The number of data points
        :return: InlineResponse20013
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['subserver', 'service', 'id', 'interval', 'count']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method show_latency_metering_of_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'subserver' is set
        if self.api_client.client_side_validation and ('subserver' not in params or
                                                       params['subserver'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `subserver` when calling `show_latency_metering_of_user`")  # noqa: E501
        # verify the required parameter 'service' is set
        if self.api_client.client_side_validation and ('service' not in params or
                                                       params['service'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `service` when calling `show_latency_metering_of_user`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `show_latency_metering_of_user`")  # noqa: E501

        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `show_latency_metering_of_user`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('count' in params and params['count'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `count` when calling `show_latency_metering_of_user`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'subserver' in params:
            query_params.append(('subserver', params['subserver']))  # noqa: E501
        if 'service' in params:
            query_params.append(('service', params['service']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/users/{id}/latency.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20013',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Vpsa
from Vpsa.api.mirroring_and_cloning_api import MirroringAndCloningApi  # noqa: E501
from Vpsa.rest import ApiException


class TestMirroringAndCloningApi(unittest.TestCase):
    """MirroringAndCloningApi unit test stubs"""

    def setUp(self):
        self.api = Vpsa.api.mirroring_and_cloning_api.MirroringAndCloningApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_mirror_snapshot_policy(self):
        """Test case for add_mirror_snapshot_policy

        """
        pass

    def test_attach_snapshot_policy_to_vpsa_mirror_job(self):
        """Test case for attach_snapshot_policy_to_vpsa_mirror_job

        """
        pass

    def test_break_remote_clone_job(self):
        """Test case for break_remote_clone_job

        """
        pass

    def test_break_vpsa_mirror_job(self):
        """Test case for break_vpsa_mirror_job

        """
        pass

    def test_clone_mirror_job(self):
        """Test case for clone_mirror_job

        """
        pass

    def test_continue_vpsa_mirror_job(self):
        """Test case for continue_vpsa_mirror_job

        """
        pass

    def test_create_remote_clone(self):
        """Test case for create_remote_clone

        """
        pass

    def test_detach_snapshot_policy_from_vol(self):
        """Test case for detach_snapshot_policy_from_vol

        """
        pass

    def test_discover_remote_vpsa(self):
        """Test case for discover_remote_vpsa

        """
        pass

    def test_get_all_remote_clones(self):
        """Test case for get_all_remote_clones

        """
        pass

    def test_get_remote_clone(self):
        """Test case for get_remote_clone

        """
        pass

    def test_get_remote_vpsa_pools(self):
        """Test case for get_remote_vpsa_pools

        """
        pass

    def test_get_snapshots(self):
        """Test case for get_snapshots

        """
        pass

    def test_get_suggested_mirror_jobs(self):
        """Test case for get_suggested_mirror_jobs

        """
        pass

    def test_pause_remote_clone(self):
        """Test case for pause_remote_clone

        """
        pass

    def test_pause_vpsa_mirror_job(self):
        """Test case for pause_vpsa_mirror_job

        """
        pass

    def test_refresh_remote_vpsa(self):
        """Test case for refresh_remote_vpsa

        """
        pass

    def test_remove_remote_vpsa(self):
        """Test case for remove_remote_vpsa

        """
        pass

    def test_resume_broken_mirror(self):
        """Test case for resume_broken_mirror

        """
        pass

    def test_resume_remote_clone_job(self):
        """Test case for resume_remote_clone_job

        """
        pass

    def test_show_remote_cgs(self):
        """Test case for show_remote_cgs

        """
        pass

    def test_show_remote_mirror_job(self):
        """Test case for show_remote_mirror_job

        """
        pass

    def test_show_remote_snapshots_on_cg(self):
        """Test case for show_remote_snapshots_on_cg

        """
        pass

    def test_show_remote_vpsa(self):
        """Test case for show_remote_vpsa

        """
        pass

    def test_show_remote_vpsas(self):
        """Test case for show_remote_vpsas

        """
        pass

    def test_show_vpsa_mirror_jobs(self):
        """Test case for show_vpsa_mirror_jobs

        """
        pass

    def test_switch_remote_clone_mode(self):
        """Test case for switch_remote_clone_mode

        """
        pass

    def test_update_mirror_rate_limit(self):
        """Test case for update_mirror_rate_limit

        """
        pass

    def test_update_mirror_wan_optimization(self):
        """Test case for update_mirror_wan_optimization

        """
        pass

    def test_update_remote_vpsa_rate(self):
        """Test case for update_remote_vpsa_rate

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import ProvisioningPortal
from ProvisioningPortal.models.update_object_account import UpdateObjectAccount  # noqa: E501
from ProvisioningPortal.rest import ApiException


class TestUpdateObjectAccount(unittest.TestCase):
    """UpdateObjectAccount unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpdateObjectAccount(self):
        """Test UpdateObjectAccount"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ProvisioningPortal.models.update_object_account.UpdateObjectAccount()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20031AppEngineTypesAppEngineType(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'internal_type': 'str',
        'ram': 'int',
        'vcpus': 'int',
        'vpsas_count': 'int'
    }

    attribute_map = {
        'name': 'name',
        'internal_type': 'internal_type',
        'ram': 'ram',
        'vcpus': 'vcpus',
        'vpsas_count': 'vpsas_count'
    }

    def __init__(self, name=None, internal_type=None, ram=None, vcpus=None, vpsas_count=None, _configuration=None):  # noqa: E501
        """InlineResponse20031AppEngineTypesAppEngineType - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._internal_type = None
        self._ram = None
        self._vcpus = None
        self._vpsas_count = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if internal_type is not None:
            self.internal_type = internal_type
        if ram is not None:
            self.ram = ram
        if vcpus is not None:
            self.vcpus = vcpus
        if vpsas_count is not None:
            self.vpsas_count = vpsas_count

    @property
    def name(self):
        """Gets the name of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501


        :return: The name of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20031AppEngineTypesAppEngineType.


        :param name: The name of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def internal_type(self):
        """Gets the internal_type of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501


        :return: The internal_type of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501
        :rtype: str
        """
        return self._internal_type

    @internal_type.setter
    def internal_type(self, internal_type):
        """Sets the internal_type of this InlineResponse20031AppEngineTypesAppEngineType.


        :param internal_type: The internal_type of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501
        :type: str
        """

        self._internal_type = internal_type

    @property
    def ram(self):
        """Gets the ram of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501


        :return: The ram of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501
        :rtype: int
        """
        return self._ram

    @ram.setter
    def ram(self, ram):
        """Sets the ram of this InlineResponse20031AppEngineTypesAppEngineType.


        :param ram: The ram of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501
        :type: int
        """

        self._ram = ram

    @property
    def vcpus(self):
        """Gets the vcpus of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501


        :return: The vcpus of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501
        :rtype: int
        """
        return self._vcpus

    @vcpus.setter
    def vcpus(self, vcpus):
        """Sets the vcpus of this InlineResponse20031AppEngineTypesAppEngineType.


        :param vcpus: The vcpus of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501
        :type: int
        """

        self._vcpus = vcpus

    @property
    def vpsas_count(self):
        """Gets the vpsas_count of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501


        :return: The vpsas_count of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501
        :rtype: int
        """
        return self._vpsas_count

    @vpsas_count.setter
    def vpsas_count(self, vpsas_count):
        """Sets the vpsas_count of this InlineResponse20031AppEngineTypesAppEngineType.


        :param vpsas_count: The vpsas_count of this InlineResponse20031AppEngineTypesAppEngineType.  # noqa: E501
        :type: int
        """

        self._vpsas_count = vpsas_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20031AppEngineTypesAppEngineType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20031AppEngineTypesAppEngineType):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20031AppEngineTypesAppEngineType):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class InlineResponse20026Data(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'vpsa_request_id': 'int',
        'allocation_zones': 'list[str]',
        'engine': 'InlineResponse20025Engine',
        'description': 'str',
        'management_url': 'str',
        'initial_passcode': 'str',
        'drive_count': 'int',
        'ip_address': 'str',
        'id': 'str',
        'time_created_gmt': 'str',
        'name': 'str',
        'cache': 'InlineResponse20026DataCache',
        'version': 'str',
        'locked_down': 'int',
        'provider': 'InlineResponse20025Provider'
    }

    attribute_map = {
        'status': 'status',
        'vpsa_request_id': 'vpsa_request_id',
        'allocation_zones': 'allocation_zones',
        'engine': 'engine',
        'description': 'description',
        'management_url': 'management_url',
        'initial_passcode': 'initial_passcode',
        'drive_count': 'drive_count',
        'ip_address': 'ip_address',
        'id': 'id',
        'time_created_gmt': 'time_created_gmt',
        'name': 'name',
        'cache': 'cache',
        'version': 'version',
        'locked_down': 'locked_down',
        'provider': 'provider'
    }

    def __init__(self, status=None, vpsa_request_id=None, allocation_zones=None, engine=None, description=None, management_url=None, initial_passcode=None, drive_count=None, ip_address=None, id=None, time_created_gmt=None, name=None, cache=None, version=None, locked_down=None, provider=None, _configuration=None):  # noqa: E501
        """InlineResponse20026Data - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._status = None
        self._vpsa_request_id = None
        self._allocation_zones = None
        self._engine = None
        self._description = None
        self._management_url = None
        self._initial_passcode = None
        self._drive_count = None
        self._ip_address = None
        self._id = None
        self._time_created_gmt = None
        self._name = None
        self._cache = None
        self._version = None
        self._locked_down = None
        self._provider = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if vpsa_request_id is not None:
            self.vpsa_request_id = vpsa_request_id
        if allocation_zones is not None:
            self.allocation_zones = allocation_zones
        if engine is not None:
            self.engine = engine
        if description is not None:
            self.description = description
        if management_url is not None:
            self.management_url = management_url
        if initial_passcode is not None:
            self.initial_passcode = initial_passcode
        if drive_count is not None:
            self.drive_count = drive_count
        if ip_address is not None:
            self.ip_address = ip_address
        if id is not None:
            self.id = id
        if time_created_gmt is not None:
            self.time_created_gmt = time_created_gmt
        if name is not None:
            self.name = name
        if cache is not None:
            self.cache = cache
        if version is not None:
            self.version = version
        if locked_down is not None:
            self.locked_down = locked_down
        if provider is not None:
            self.provider = provider

    @property
    def status(self):
        """Gets the status of this InlineResponse20026Data.  # noqa: E501


        :return: The status of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20026Data.


        :param status: The status of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def vpsa_request_id(self):
        """Gets the vpsa_request_id of this InlineResponse20026Data.  # noqa: E501

        When VPSA creation is moderated, this is the creation request ID.  # noqa: E501

        :return: The vpsa_request_id of this InlineResponse20026Data.  # noqa: E501
        :rtype: int
        """
        return self._vpsa_request_id

    @vpsa_request_id.setter
    def vpsa_request_id(self, vpsa_request_id):
        """Sets the vpsa_request_id of this InlineResponse20026Data.

        When VPSA creation is moderated, this is the creation request ID.  # noqa: E501

        :param vpsa_request_id: The vpsa_request_id of this InlineResponse20026Data.  # noqa: E501
        :type: int
        """

        self._vpsa_request_id = vpsa_request_id

    @property
    def allocation_zones(self):
        """Gets the allocation_zones of this InlineResponse20026Data.  # noqa: E501


        :return: The allocation_zones of this InlineResponse20026Data.  # noqa: E501
        :rtype: list[str]
        """
        return self._allocation_zones

    @allocation_zones.setter
    def allocation_zones(self, allocation_zones):
        """Sets the allocation_zones of this InlineResponse20026Data.


        :param allocation_zones: The allocation_zones of this InlineResponse20026Data.  # noqa: E501
        :type: list[str]
        """

        self._allocation_zones = allocation_zones

    @property
    def engine(self):
        """Gets the engine of this InlineResponse20026Data.  # noqa: E501


        :return: The engine of this InlineResponse20026Data.  # noqa: E501
        :rtype: InlineResponse20025Engine
        """
        return self._engine

    @engine.setter
    def engine(self, engine):
        """Sets the engine of this InlineResponse20026Data.


        :param engine: The engine of this InlineResponse20026Data.  # noqa: E501
        :type: InlineResponse20025Engine
        """

        self._engine = engine

    @property
    def description(self):
        """Gets the description of this InlineResponse20026Data.  # noqa: E501


        :return: The description of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InlineResponse20026Data.


        :param description: The description of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def management_url(self):
        """Gets the management_url of this InlineResponse20026Data.  # noqa: E501


        :return: The management_url of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._management_url

    @management_url.setter
    def management_url(self, management_url):
        """Sets the management_url of this InlineResponse20026Data.


        :param management_url: The management_url of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._management_url = management_url

    @property
    def initial_passcode(self):
        """Gets the initial_passcode of this InlineResponse20026Data.  # noqa: E501


        :return: The initial_passcode of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._initial_passcode

    @initial_passcode.setter
    def initial_passcode(self, initial_passcode):
        """Sets the initial_passcode of this InlineResponse20026Data.


        :param initial_passcode: The initial_passcode of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._initial_passcode = initial_passcode

    @property
    def drive_count(self):
        """Gets the drive_count of this InlineResponse20026Data.  # noqa: E501


        :return: The drive_count of this InlineResponse20026Data.  # noqa: E501
        :rtype: int
        """
        return self._drive_count

    @drive_count.setter
    def drive_count(self, drive_count):
        """Sets the drive_count of this InlineResponse20026Data.


        :param drive_count: The drive_count of this InlineResponse20026Data.  # noqa: E501
        :type: int
        """

        self._drive_count = drive_count

    @property
    def ip_address(self):
        """Gets the ip_address of this InlineResponse20026Data.  # noqa: E501


        :return: The ip_address of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this InlineResponse20026Data.


        :param ip_address: The ip_address of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def id(self):
        """Gets the id of this InlineResponse20026Data.  # noqa: E501


        :return: The id of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20026Data.


        :param id: The id of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def time_created_gmt(self):
        """Gets the time_created_gmt of this InlineResponse20026Data.  # noqa: E501


        :return: The time_created_gmt of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._time_created_gmt

    @time_created_gmt.setter
    def time_created_gmt(self, time_created_gmt):
        """Sets the time_created_gmt of this InlineResponse20026Data.


        :param time_created_gmt: The time_created_gmt of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._time_created_gmt = time_created_gmt

    @property
    def name(self):
        """Gets the name of this InlineResponse20026Data.  # noqa: E501


        :return: The name of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20026Data.


        :param name: The name of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def cache(self):
        """Gets the cache of this InlineResponse20026Data.  # noqa: E501


        :return: The cache of this InlineResponse20026Data.  # noqa: E501
        :rtype: InlineResponse20026DataCache
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse20026Data.


        :param cache: The cache of this InlineResponse20026Data.  # noqa: E501
        :type: InlineResponse20026DataCache
        """

        self._cache = cache

    @property
    def version(self):
        """Gets the version of this InlineResponse20026Data.  # noqa: E501


        :return: The version of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InlineResponse20026Data.


        :param version: The version of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def locked_down(self):
        """Gets the locked_down of this InlineResponse20026Data.  # noqa: E501


        :return: The locked_down of this InlineResponse20026Data.  # noqa: E501
        :rtype: int
        """
        return self._locked_down

    @locked_down.setter
    def locked_down(self, locked_down):
        """Sets the locked_down of this InlineResponse20026Data.


        :param locked_down: The locked_down of this InlineResponse20026Data.  # noqa: E501
        :type: int
        """

        self._locked_down = locked_down

    @property
    def provider(self):
        """Gets the provider of this InlineResponse20026Data.  # noqa: E501


        :return: The provider of this InlineResponse20026Data.  # noqa: E501
        :rtype: InlineResponse20025Provider
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this InlineResponse20026Data.


        :param provider: The provider of this InlineResponse20026Data.  # noqa: E501
        :type: InlineResponse20025Provider
        """

        self._provider = provider

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20026Data, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20026Data):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20026Data):
            return True

        return self.to_dict() != other.to_dict()
